Memorystore

Struct Memorystore 

pub struct Memorystore { /* private fields */ }
Implements a client for the Memorystore API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = Memorystore::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_instances()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Service describing handlers for resources

Configuration

To configure Memorystore use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://memorystore.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

Memorystore holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap Memorystore in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl Memorystore

pub fn builder() -> ClientBuilder

Returns a builder for Memorystore.

let client = Memorystore::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: Memorystore + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn list_instances(&self) -> ListInstances

Lists Instances in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore, parent: &str
) -> Result<()> {
    let mut list = client.list_instances()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_instance(&self) -> GetInstance

Gets details of a single Instance.

Example
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore, name: &str
) -> Result<()> {
    let response = client.get_instance()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_instance(&self) -> CreateInstance

Creates a new Instance in a given project and location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memorystore_v1::model::Instance;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore, parent: &str
) -> Result<()> {
    let response = client.create_instance()
        .set_parent(parent)
        .set_instance_id("instance_id_value")
        .set_instance(
            Instance::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_instance(&self) -> UpdateInstance

Updates the parameters of a single Instance.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_memorystore_v1::model::Instance;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore, name: &str
) -> Result<()> {
    let response = client.update_instance()
        .set_instance(
            Instance::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_instance(&self) -> DeleteInstance

Deletes a single Instance.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore, name: &str
) -> Result<()> {
    client.delete_instance()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn get_certificate_authority(&self) -> GetCertificateAuthority

Gets details about the certificate authority for an Instance.

Example
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore
) -> Result<()> {
    let response = client.get_certificate_authority()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn reschedule_maintenance(&self) -> RescheduleMaintenance

Reschedules upcoming maintenance event.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore
) -> Result<()> {
    let response = client.reschedule_maintenance()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_backup_collections(&self) -> ListBackupCollections

Lists all backup collections owned by a consumer project in either the specified location (region) or all locations.

If location_id is specified as - (wildcard), then all regions available to the project are queried, and the results are aggregated.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore, parent: &str
) -> Result<()> {
    let mut list = client.list_backup_collections()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_backup_collection(&self) -> GetBackupCollection

Get a backup collection.

Example
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore, name: &str
) -> Result<()> {
    let response = client.get_backup_collection()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_backups(&self) -> ListBackups

Lists all backups owned by a backup collection.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore, parent: &str
) -> Result<()> {
    let mut list = client.list_backups()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_backup(&self) -> GetBackup

Gets the details of a specific backup.

Example
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore, name: &str
) -> Result<()> {
    let response = client.get_backup()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_backup(&self) -> DeleteBackup

Deletes a specific backup.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore, name: &str
) -> Result<()> {
    client.delete_backup()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn export_backup(&self) -> ExportBackup

Exports a specific backup to a customer target Cloud Storage URI.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore
) -> Result<()> {
    let response = client.export_backup()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn backup_instance(&self) -> BackupInstance

Backup Instance. If this is the first time a backup is being created, a backup collection will be created at the backend, and this backup belongs to this collection. Both collection and backup will have a resource name. Backup will be executed for each shard. A replica (primary if nonHA) will be selected to perform the execution. Backup call will be rejected if there is an ongoing backup or update operation. Be aware that during preview, if the instance’s internal software version is too old, critical update will be performed before actual backup. Once the internal software version is updated to the minimum version required by the backup feature, subsequent backups will not require critical update. After preview, there will be no critical update needed for backup.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore
) -> Result<()> {
    let response = client.backup_instance()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_memorystore_v1::Result;
async fn sample(
   client: &Memorystore
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}