#[non_exhaustive]pub enum ServerCaMode {
Unspecified,
GoogleManagedPerInstanceCa,
GoogleManagedSharedCa,
CustomerManagedCasCa,
UnknownValue(UnknownValue),
}Expand description
The Server CA mode for the instance.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Server CA mode not specified.
GoogleManagedPerInstanceCa
Each instance has its own Google-managed CA.
The instance uses a Google-managed shared CA for the instance’s region.
CustomerManagedCasCa
The instance uses a customer-managed CA from CAS.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ServerCaMode::value or ServerCaMode::name.
Implementations