#[non_exhaustive]pub struct ConnectionDetail {
pub connection: Option<Connection>,
/* private fields */
}Expand description
Information of each PSC connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection: Option<Connection>A PSC connection to an instance could either be created through Service Connectivity Automation (auto connection) during the cluster creation, or it could be created by customer themeslves (user-created connection).
Implementations
Sourceimpl ConnectionDetail
impl ConnectionDetail
Sourcepub fn set_connection<T: Into<Option<Connection>>>(self, v: T) -> Self
pub fn set_connection<T: Into<Option<Connection>>>(self, v: T) -> Self
Sets the value of connection.
Note that all the setters affecting connection are mutually
exclusive.
Example
use google_cloud_memorystore_v1::model::PscAutoConnection;
let x = ConnectionDetail::new().set_connection(Some(
google_cloud_memorystore_v1::model::instance::connection_detail::Connection::PscAutoConnection(PscAutoConnection::default().into())));Sourcepub fn psc_auto_connection(&self) -> Option<&Box<PscAutoConnection>>
pub fn psc_auto_connection(&self) -> Option<&Box<PscAutoConnection>>
The value of connection
if it holds a PscAutoConnection, None if the field is not set or
holds a different branch.
Sourcepub fn set_psc_auto_connection<T: Into<Box<PscAutoConnection>>>(
self,
v: T,
) -> Self
pub fn set_psc_auto_connection<T: Into<Box<PscAutoConnection>>>( self, v: T, ) -> Self
Sets the value of connection
to hold a PscAutoConnection.
Note that all the setters affecting connection are
mutually exclusive.
Example
use google_cloud_memorystore_v1::model::PscAutoConnection;
let x = ConnectionDetail::new().set_psc_auto_connection(PscAutoConnection::default()/* use setters */);
assert!(x.psc_auto_connection().is_some());
assert!(x.psc_connection().is_none());Sourcepub fn psc_connection(&self) -> Option<&Box<PscConnection>>
pub fn psc_connection(&self) -> Option<&Box<PscConnection>>
The value of connection
if it holds a PscConnection, None if the field is not set or
holds a different branch.
Sourcepub fn set_psc_connection<T: Into<Box<PscConnection>>>(self, v: T) -> Self
pub fn set_psc_connection<T: Into<Box<PscConnection>>>(self, v: T) -> Self
Sets the value of connection
to hold a PscConnection.
Note that all the setters affecting connection are
mutually exclusive.
Example
use google_cloud_memorystore_v1::model::PscConnection;
let x = ConnectionDetail::new().set_psc_connection(PscConnection::default()/* use setters */);
assert!(x.psc_connection().is_some());
assert!(x.psc_auto_connection().is_none());Trait Implementations
Sourceimpl Clone for ConnectionDetail
impl Clone for ConnectionDetail
Sourcefn clone(&self) -> ConnectionDetail
fn clone(&self) -> ConnectionDetail
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ConnectionDetail
impl Debug for ConnectionDetail
Sourceimpl Default for ConnectionDetail
impl Default for ConnectionDetail
Sourcefn default() -> ConnectionDetail
fn default() -> ConnectionDetail
Sourceimpl Message for ConnectionDetail
impl Message for ConnectionDetail
Sourceimpl PartialEq for ConnectionDetail
impl PartialEq for ConnectionDetail
impl StructuralPartialEq for ConnectionDetail