#[non_exhaustive]pub struct AddTokenAuthUserRequest {
pub instance: String,
pub token_auth_user: String,
/* private fields */
}Expand description
Request message for AddTokenAuthUser.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance: StringRequired. The instance resource that this token auth user will be added for. Format: projects/{project}/locations/{location}/instances/{instance}
token_auth_user: StringRequired. The name of the token auth user to add.
Implementations
Sourceimpl AddTokenAuthUserRequest
impl AddTokenAuthUserRequest
Sourcepub fn set_instance<T: Into<String>>(self, v: T) -> Self
pub fn set_instance<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_token_auth_user<T: Into<String>>(self, v: T) -> Self
pub fn set_token_auth_user<T: Into<String>>(self, v: T) -> Self
Sets the value of token_auth_user.
Example
ⓘ
let x = AddTokenAuthUserRequest::new().set_token_auth_user("example");Trait Implementations
Sourceimpl Clone for AddTokenAuthUserRequest
impl Clone for AddTokenAuthUserRequest
Sourcefn clone(&self) -> AddTokenAuthUserRequest
fn clone(&self) -> AddTokenAuthUserRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddTokenAuthUserRequest
impl Debug for AddTokenAuthUserRequest
Sourceimpl Default for AddTokenAuthUserRequest
impl Default for AddTokenAuthUserRequest
Sourcefn default() -> AddTokenAuthUserRequest
fn default() -> AddTokenAuthUserRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for AddTokenAuthUserRequest
impl Message for AddTokenAuthUserRequest
Sourceimpl PartialEq for AddTokenAuthUserRequest
impl PartialEq for AddTokenAuthUserRequest
impl StructuralPartialEq for AddTokenAuthUserRequest