#[non_exhaustive]pub struct BackupCollection {
pub name: String,
pub instance_uid: String,
pub instance: String,
pub kms_key: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub total_backup_size_bytes: i64,
pub total_backup_count: i64,
pub last_backup_time: Option<Timestamp>,
/* private fields */
}Expand description
BackupCollection of an instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Full resource path of the backup collection.
instance_uid: StringOutput only. The instance uid of the backup collection.
instance: StringOutput only. The full resource path of the instance the backup collection belongs to. Example: projects/{project}/locations/{location}/instances/{instance}
kms_key: StringOutput only. The KMS key used to encrypt the backups under this backup collection.
uid: StringOutput only. System assigned unique identifier of the backup collection.
create_time: Option<Timestamp>Output only. The time when the backup collection was created.
total_backup_size_bytes: i64Output only. Total size of all backups in the backup collection.
total_backup_count: i64Output only. Total number of backups in the backup collection.
last_backup_time: Option<Timestamp>Output only. The last time a backup was created in the backup collection.
Implementations
Sourceimpl BackupCollection
impl BackupCollection
Sourcepub fn set_instance_uid<T: Into<String>>(self, v: T) -> Self
pub fn set_instance_uid<T: Into<String>>(self, v: T) -> Self
Sets the value of instance_uid.
Example
let x = BackupCollection::new().set_instance_uid("example");Sourcepub fn set_instance<T: Into<String>>(self, v: T) -> Self
pub fn set_instance<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = BackupCollection::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = BackupCollection::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = BackupCollection::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_total_backup_size_bytes<T: Into<i64>>(self, v: T) -> Self
pub fn set_total_backup_size_bytes<T: Into<i64>>(self, v: T) -> Self
Sets the value of total_backup_size_bytes.
Example
let x = BackupCollection::new().set_total_backup_size_bytes(42);Sourcepub fn set_total_backup_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_total_backup_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of total_backup_count.
Example
let x = BackupCollection::new().set_total_backup_count(42);Sourcepub fn set_last_backup_time<T>(self, v: T) -> Self
pub fn set_last_backup_time<T>(self, v: T) -> Self
Sets the value of last_backup_time.
Example
use wkt::Timestamp;
let x = BackupCollection::new().set_last_backup_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_last_backup_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_backup_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_backup_time.
Example
use wkt::Timestamp;
let x = BackupCollection::new().set_or_clear_last_backup_time(Some(Timestamp::default()/* use setters */));
let x = BackupCollection::new().set_or_clear_last_backup_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for BackupCollection
impl Clone for BackupCollection
Sourcefn clone(&self) -> BackupCollection
fn clone(&self) -> BackupCollection
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BackupCollection
impl Debug for BackupCollection
Sourceimpl Default for BackupCollection
impl Default for BackupCollection
Sourcefn default() -> BackupCollection
fn default() -> BackupCollection
Sourceimpl Message for BackupCollection
impl Message for BackupCollection
Sourceimpl PartialEq for BackupCollection
impl PartialEq for BackupCollection
impl StructuralPartialEq for BackupCollection