#[non_exhaustive]pub struct ListBackupCollectionsResponse {
pub backup_collections: Vec<BackupCollection>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response for ListBackupCollections.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backup_collections: Vec<BackupCollection>A list of backupCollections in the project.
If the location_id in the parent field of the request is “-”, all regions
available to the project are queried, and the results aggregated.
If in such an aggregated query a location is unavailable, a placeholder
backupCollection entry is included in the response with the name field
set to a value of the form
projects/{project_id}/locations/{location_id}/backupCollections/- and the
status field set to ERROR and status_message field set to “location not
available for ListBackupCollections”.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more results in the list.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListBackupCollectionsResponse
impl ListBackupCollectionsResponse
Sourcepub fn set_backup_collections<T, V>(self, v: T) -> Self
pub fn set_backup_collections<T, V>(self, v: T) -> Self
Sets the value of backup_collections.
Example
use google_cloud_memorystore_v1::model::BackupCollection;
let x = ListBackupCollectionsResponse::new()
.set_backup_collections([
BackupCollection::default()/* use setters */,
BackupCollection::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = ListBackupCollectionsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
let x = ListBackupCollectionsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListBackupCollectionsResponse
impl Clone for ListBackupCollectionsResponse
Sourcefn clone(&self) -> ListBackupCollectionsResponse
fn clone(&self) -> ListBackupCollectionsResponse
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ListBackupCollectionsResponse
impl Default for ListBackupCollectionsResponse
Sourcefn default() -> ListBackupCollectionsResponse
fn default() -> ListBackupCollectionsResponse
impl StructuralPartialEq for ListBackupCollectionsResponse