#[non_exhaustive]pub struct ListTokenAuthUsersResponse {
pub token_auth_users: Vec<TokenAuthUser>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ListTokenAuthUsers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.token_auth_users: Vec<TokenAuthUser>A list of token auth users in the project.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more results in the list.
unreachable: Vec<String>Unordered list. Token auth users that could not be reached.
Implementations
Sourceimpl ListTokenAuthUsersResponse
impl ListTokenAuthUsersResponse
Sourcepub fn set_token_auth_users<T, V>(self, v: T) -> Self
pub fn set_token_auth_users<T, V>(self, v: T) -> Self
Sets the value of token_auth_users.
Example
ⓘ
use google_cloud_memorystore_v1::model::TokenAuthUser;
let x = ListTokenAuthUsersResponse::new()
.set_token_auth_users([
TokenAuthUser::default()/* use setters */,
TokenAuthUser::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListTokenAuthUsersResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListTokenAuthUsersResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListTokenAuthUsersResponse
impl Clone for ListTokenAuthUsersResponse
Sourcefn clone(&self) -> ListTokenAuthUsersResponse
fn clone(&self) -> ListTokenAuthUsersResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListTokenAuthUsersResponse
impl Debug for ListTokenAuthUsersResponse
Sourceimpl Default for ListTokenAuthUsersResponse
impl Default for ListTokenAuthUsersResponse
Sourcefn default() -> ListTokenAuthUsersResponse
fn default() -> ListTokenAuthUsersResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListTokenAuthUsersResponse
impl Message for ListTokenAuthUsersResponse
impl StructuralPartialEq for ListTokenAuthUsersResponse