#[non_exhaustive]pub struct MigrationConfig {
pub state: State,
pub force_finish_migration: bool,
pub source: Option<Source>,
/* private fields */
}Expand description
Configuration for the migration of an instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.state: StateOutput only. Migration state of the instance.
force_finish_migration: boolOutput only. Represents a boolean flag to force migration finalization without offset catch up validation between source and target before stopping replication.
source: Option<Source>Details about the migration source.
Implementations
Sourceimpl MigrationConfig
impl MigrationConfig
Sourcepub fn set_force_finish_migration<T: Into<bool>>(self, v: T) -> Self
pub fn set_force_finish_migration<T: Into<bool>>(self, v: T) -> Self
Sets the value of force_finish_migration.
Example
ⓘ
let x = MigrationConfig::new().set_force_finish_migration(true);Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
ⓘ
use google_cloud_memorystore_v1::model::SelfManagedSource;
let x = MigrationConfig::new().set_source(Some(
google_cloud_memorystore_v1::model::migration_config::Source::SelfManagedSource(SelfManagedSource::default().into())));Sourcepub fn self_managed_source(&self) -> Option<&Box<SelfManagedSource>>
pub fn self_managed_source(&self) -> Option<&Box<SelfManagedSource>>
The value of source
if it holds a SelfManagedSource, None if the field is not set or
holds a different branch.
Sourcepub fn set_self_managed_source<T: Into<Box<SelfManagedSource>>>(
self,
v: T,
) -> Self
pub fn set_self_managed_source<T: Into<Box<SelfManagedSource>>>( self, v: T, ) -> Self
Sets the value of source
to hold a SelfManagedSource.
Note that all the setters affecting source are
mutually exclusive.
Example
ⓘ
use google_cloud_memorystore_v1::model::SelfManagedSource;
let x = MigrationConfig::new().set_self_managed_source(SelfManagedSource::default()/* use setters */);
assert!(x.self_managed_source().is_some());Trait Implementations
Sourceimpl Clone for MigrationConfig
impl Clone for MigrationConfig
Sourcefn clone(&self) -> MigrationConfig
fn clone(&self) -> MigrationConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MigrationConfig
impl Debug for MigrationConfig
Sourceimpl Default for MigrationConfig
impl Default for MigrationConfig
Sourcefn default() -> MigrationConfig
fn default() -> MigrationConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for MigrationConfig
impl Message for MigrationConfig
Sourceimpl PartialEq for MigrationConfig
impl PartialEq for MigrationConfig
impl StructuralPartialEq for MigrationConfig