SelfManagedSource

Struct SelfManagedSource 

#[non_exhaustive]
pub struct SelfManagedSource { pub ip_address: String, pub port: i32, pub network_attachment: String, /* private fields */ }
Details of the self-managed source instance.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
ip_address: String

Required. The IP address of the source instance. This IP address should be a stable IP address that can be accessed by the Memorystore instance throughout the migration process.

port: i32

Required. The port of the source instance. This port should be a stable port that can be accessed by the Memorystore instance throughout the migration process.

network_attachment: String

Required. The resource name of the Private Service Connect Network Attachment used to establish connectivity to the source instance. This network attachment has the following requirements:

  1. It must be in the same project as the Memorystore instance.
  2. It must be in the same region as the Memorystore instance.
  3. The subnet attached to the network attachment must be in the same VPC network as the source instance nodes.

Format: projects/{project}/regions/{region}/networkAttachments/{network_attachment}

Implementations

Source

impl SelfManagedSource

pub fn new() -> Self

Creates a new default instance.

pub fn set_ip_address<T: Into<String>>(self, v: T) -> Self

Sets the value of ip_address.

Example
let x = SelfManagedSource::new().set_ip_address("example");
pub fn set_port<T: Into<i32>>(self, v: T) -> Self

Sets the value of port.

Example
let x = SelfManagedSource::new().set_port(42);
pub fn set_network_attachment<T: Into<String>>(self, v: T) -> Self

Sets the value of network_attachment.

Example
let x = SelfManagedSource::new().set_network_attachment("example");