#[non_exhaustive]pub struct StartMigrationRequest {
pub name: String,
pub source: Option<Source>,
/* private fields */
}Expand description
Request for StartMigration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the instance to start migration on. Format: projects/{project}/locations/{location}/instances/{instance}
source: Option<Source>Defines the source of the migration.
Implementations
Sourceimpl StartMigrationRequest
impl StartMigrationRequest
Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
ⓘ
use google_cloud_memorystore_v1::model::SelfManagedSource;
let x = StartMigrationRequest::new().set_source(Some(
google_cloud_memorystore_v1::model::start_migration_request::Source::SelfManagedSource(SelfManagedSource::default().into())));Sourcepub fn self_managed_source(&self) -> Option<&Box<SelfManagedSource>>
pub fn self_managed_source(&self) -> Option<&Box<SelfManagedSource>>
The value of source
if it holds a SelfManagedSource, None if the field is not set or
holds a different branch.
Sourcepub fn set_self_managed_source<T: Into<Box<SelfManagedSource>>>(
self,
v: T,
) -> Self
pub fn set_self_managed_source<T: Into<Box<SelfManagedSource>>>( self, v: T, ) -> Self
Sets the value of source
to hold a SelfManagedSource.
Note that all the setters affecting source are
mutually exclusive.
Example
ⓘ
use google_cloud_memorystore_v1::model::SelfManagedSource;
let x = StartMigrationRequest::new().set_self_managed_source(SelfManagedSource::default()/* use setters */);
assert!(x.self_managed_source().is_some());Trait Implementations
Sourceimpl Clone for StartMigrationRequest
impl Clone for StartMigrationRequest
Sourcefn clone(&self) -> StartMigrationRequest
fn clone(&self) -> StartMigrationRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StartMigrationRequest
impl Debug for StartMigrationRequest
Sourceimpl Default for StartMigrationRequest
impl Default for StartMigrationRequest
Sourcefn default() -> StartMigrationRequest
fn default() -> StartMigrationRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for StartMigrationRequest
impl Message for StartMigrationRequest
Sourceimpl PartialEq for StartMigrationRequest
impl PartialEq for StartMigrationRequest
impl StructuralPartialEq for StartMigrationRequest