#[non_exhaustive]pub struct SelfManagedSource {
pub ip_address: String,
pub port: i32,
pub network_attachment: String,
/* private fields */
}Expand description
Details of the self-managed source instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ip_address: StringRequired. The IP address of the source instance. This IP address should be a stable IP address that can be accessed by the Memorystore instance throughout the migration process.
port: i32Required. The port of the source instance. This port should be a stable port that can be accessed by the Memorystore instance throughout the migration process.
network_attachment: StringRequired. The resource name of the Private Service Connect Network Attachment used to establish connectivity to the source instance. This network attachment has the following requirements:
- It must be in the same project as the Memorystore instance.
- It must be in the same region as the Memorystore instance.
- The subnet attached to the network attachment must be in the same VPC network as the source instance nodes.
Format: projects/{project}/regions/{region}/networkAttachments/{network_attachment}
Implementations
Sourceimpl SelfManagedSource
impl SelfManagedSource
Sourcepub fn set_ip_address<T: Into<String>>(self, v: T) -> Self
pub fn set_ip_address<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_network_attachment<T: Into<String>>(self, v: T) -> Self
pub fn set_network_attachment<T: Into<String>>(self, v: T) -> Self
Sets the value of network_attachment.
Example
ⓘ
let x = SelfManagedSource::new().set_network_attachment("example");Trait Implementations
Sourceimpl Clone for SelfManagedSource
impl Clone for SelfManagedSource
Sourcefn clone(&self) -> SelfManagedSource
fn clone(&self) -> SelfManagedSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelfManagedSource
impl Debug for SelfManagedSource
Sourceimpl Default for SelfManagedSource
impl Default for SelfManagedSource
Sourcefn default() -> SelfManagedSource
fn default() -> SelfManagedSource
Returns the “default value” for a type. Read more
Sourceimpl Message for SelfManagedSource
impl Message for SelfManagedSource
Sourceimpl PartialEq for SelfManagedSource
impl PartialEq for SelfManagedSource
impl StructuralPartialEq for SelfManagedSource